# fzf-bin

https://github.com/junegunn/fzf

**fzf** is an interactive Unix filter for command-line that can be used with any list; files, command history, processes, hostnames, bookmarks, git commits, etc..

see original [repository](https://github.com/junegunn/fzf) for more information.

![image](https://raw.githubusercontent.com/junegunn/i/master/fzf-preview.png)

This is a python wrapper that can be installed with pip.

## install

```sh
pip install fzf-bin
```
